from django import template

register = template.Library()


@register.inclusion_tag('languages.html')
def languages(flag_type='', **kwargs):
    """
    Templatetag languages

    :param flag_type: Default empty, It acepts the string 'square'
    :param kwargs: Classes to HTML tags
    :return: A dict with classes
    """
    if flag_type == 'square':
        flag_type = 'flag-icon-square'
    default = dict(li_class='', a_class='')
    classes = dict(default, **kwargs)
    return {
        'icon_class': flag_type,
        'classes': classes,
    }


from django.test import TestCase

from django_translation_flags.templatetags.flags import languages


class TemplateTagFlagTest(TestCase):
    def setUp(self):
        self.languages = languages()

    def test_languages_return_has_key(self):
        expected = ['icon_class', 'classes']
        self.assertListEqual(expected, list(self.languages.keys()))

    def test_languages_return_has_classes_key(self):
        expected = ['li_class', 'a_class']
        self.assertListEqual(expected, list(self.languages['classes'].keys()))

    def test_languages_return_flag_type(self):
        """Must return empty when given no param"""
        self.assertEqual('', self.languages['icon_class'])

    def test_languages_return_li_class(self):
        """Must return empty when given no param"""
        self.assertEqual('', self.languages['classes']['li_class'])

    def test_languages_return_a_class(self):
        """Must return empty when given no param"""
        self.assertEqual('', self.languages['classes']['a_class'])


class TemplateTagFlagTypeTest(TestCase):
    def setUp(self):
        self.languages = languages('square')

    def test_languages_return_flag_type_square(self):
        """Must return the class flag-icon-square when given the string 'square' as param"""
        self.assertEqual('flag-icon-square', self.languages['icon_class'])


class TemplateTagKwargsTest(TestCase):
    def setUp(self):
        self.languages = languages(li_class='your-li-class', a_class='your-a-class')

    def test_languages_return_li_class(self):
        """Must return class when given the key li_class"""
        self.assertEqual('your-li-class', self.languages['classes']['li_class'])

    def test_languages_return_a_class(self):
        """Must return class when given the key a_class"""
        self.assertEqual('your-a-class', self.languages['classes']['a_class'])



from django.test import TestCase
from django_translation_flags import app_settings


class AppSettingsTest(TestCase):
    def test_has_defined(self):
        """Must have the MIDDLEWARE defined in app_settings.py"""
        self.assertTrue(hasattr(app_settings, 'MIDDLEWARE'))



from django.utils.translation import gettext_lazy as _
SECRET_KEY = 'fake-key-01234567890$:)'
INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    "django_translation_flags",
]

ROOT_URLCONF = 'django_translation_flags.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': 'mydatabase',
    }
}

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True
LANGUAGES = (
    ('en', _('English')),
    ('pt-br', _('Brazilian Portuguese'))
)

STATIC_URL = '/static/'


from django.test import TestCase
from django.template import Context, Template


class TemplateTagTest(TestCase):
    def setUp(self):
        context = Context({})
        template_to_render = Template(
            '{% load flags %}'
            '{% languages %}'
        )
        self.rendered_template = template_to_render.render(context)

    def test_has_tags(self):
        """Must contains the tags in HTML"""
        tags = (
            '<li',
            '<a tabindex="-1" href="#pt-br"',
            '<a tabindex="-1" href="#en"',
            '<span class="flag-icon flag-icon-pt-br',
            '<span class="flag-icon flag-icon-en'
        )
        for text in tags:
            with self.subTest():
                self.assertIn(text, self.rendered_template)

    def test_has_link_css(self):
        """Must have the link tag with css registration"""
        contents = [
            '<link rel="stylesheet" type="text/css" href="/static/css/django-translation-flags.min.css">'
        ]

        for expected in contents:
            with self.subTest():
                self.assertIn(expected, self.rendered_template)

    def test_has_jquery_function(self):
        """Must have the script tag with jQuery registration"""
        contents = [
            '<script type="text/javascript">',
            'function set_language(language) {',
            '$(\'input[name="language"]\').val(language);',
            '$(\'form#setlang\').submit();',
            '}',
            '</script>',
        ]

        for expected in contents:
            with self.subTest():
                self.assertIn(expected, self.rendered_template)

    def test_has_no_class_square(self):
        """Don't Must contains the class 'flag-icon-square' in HTML"""
        self.assertNotIn('flag-icon-square', self.rendered_template)


class TemplatetagWithSquareTest(TestCase):
    def setUp(self):
        context = Context({})
        template_to_render = Template(
            '{% load flags %}'
            "{% languages 'square'  %}"
        )
        self.rendered_template = template_to_render.render(context)

    def test_has_class(self):
        """Must contains the class 'flag-icon-square' in HTML"""
        icon_class = 'flag-icon-square'
        self.assertIn(icon_class, self.rendered_template)

    def test_count_class(self):
        """Must count the class 'flag-icon-square' in HTML"""
        self.assertEqual(2, self.rendered_template.count('flag-icon-square'))


class TemplatetagWithKwargsTest(TestCase):
    def setUp(self):
        context = Context({})
        template_to_render = Template(
            '{% load flags %}'
            "{% languages 'square' li_class='your-li-class' a_class='your-a-class' %}"
        )
        self.rendered_template = template_to_render.render(context)

    def test_has_class(self):
        """Must contains the classes in HTML"""
        kw_classes = ['your-li-class', 'your-a-class']

        for expected in kw_classes:
            with self.subTest():
                self.assertIn(expected, self.rendered_template)

    def test_count_li_class(self):
        """Must count the class 'your-li-class' in HTML"""
        self.assertEqual(2, self.rendered_template.count('your-li-class'))

    def test_count_a_class(self):
        """Must count the class 'flag-icon-square' in HTML"""
        self.assertEqual(2, self.rendered_template.count('your-a-class'))



import os
from builtins import RuntimeError

from setuptools import find_packages, setup

short_description = 'Internationalization with flags of main languages, ' \
                    'It lets easy to integrate the Django i18n in yours templates'

# noinspection PyBroadException
try:
    # noinspection PyPackageRequirements
    import pypandoc

    long_description = pypandoc.convert('README.md', 'rst')
except RuntimeError:
    long_description = short_description

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-translation-flags',
    version='1.0.4',
    packages=find_packages(),
    include_package_data=True,
    license='MIT License',
    description=short_description,
    long_description=long_description,
    url='http://github.com/silviolleite/django-translation-flags',
    author='Silvio Luis Leite',
    author_email='silviolleite@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 2.1',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
